Vivarium
========

.. image:: https://travis-ci.org/ihmeuw/vivarium.svg?branch=master
    :target: https://travis-ci.org/ihmeuw/vivarium
    :alt: Latest Version

.. image:: https://readthedocs.org/projects/vivarium/badge/?version=latest
    :target: https://vivarium.readthedocs.io/en/latest/?badge=latest
    :alt: Latest Docs

Vivarium is a framework for microsimulation written using standard scientific Python tools.
